[U-Boot] [PATCH v5 2/9] Rename run_command() to builtin_run_command()

Simon Glass sjg at chromium.org
Wed Feb 15 06:59:19 CET 2012


The current run_command() is only one of the parsing options - the other
is hush. We should not call run_command() when the hush parser is being
used. So we rename this function to better explain its purpose.

Signed-off-by: Simon Glass <sjg at chromium.org>
---
Changes in v4:
- Minor comment change for call to builtin_run_command()

Changes in v5:
- Adjust commit message to make it easier for Mike to grok

 arch/arm/cpu/arm926ejs/kirkwood/cpu.c |    2 +-
 board/esd/common/auto_update.c        |    2 +-
 board/esd/common/cmd_loadpci.c        |    2 +-
 board/esd/du440/du440.c               |    2 +-
 common/cmd_bedbug.c                   |    2 +-
 common/cmd_bootm.c                    |    2 +-
 common/cmd_source.c                   |    4 ++--
 common/main.c                         |    9 +++++----
 include/common.h                      |    2 +-
 9 files changed, 14 insertions(+), 13 deletions(-)

diff --git a/arch/arm/cpu/arm926ejs/kirkwood/cpu.c b/arch/arm/cpu/arm926ejs/kirkwood/cpu.c
index 8f04ddb..54d15ea 100644
--- a/arch/arm/cpu/arm926ejs/kirkwood/cpu.c
+++ b/arch/arm/cpu/arm926ejs/kirkwood/cpu.c
@@ -227,7 +227,7 @@ static void kw_sysrst_action(void)
 
 	debug("Starting %s process...\n", __FUNCTION__);
 #if !defined(CONFIG_SYS_HUSH_PARSER)
-	ret = run_command (s, 0);
+	ret = builtin_run_command(s, 0);
 #else
 	ret = parse_string_outer(s, FLAG_PARSE_SEMICOLON
 				  | FLAG_EXIT_FROM_LOOP);
diff --git a/board/esd/common/auto_update.c b/board/esd/common/auto_update.c
index fc60545..4cc15fa 100644
--- a/board/esd/common/auto_update.c
+++ b/board/esd/common/auto_update.c
@@ -169,7 +169,7 @@ int au_do_update(int i, long sz)
 				k++;
 			}
 
-			run_command(addr, 0);
+			builtin_run_command(addr, 0);
 			return 0;
 		}
 
diff --git a/board/esd/common/cmd_loadpci.c b/board/esd/common/cmd_loadpci.c
index 8f4ad84..c2bf279 100644
--- a/board/esd/common/cmd_loadpci.c
+++ b/board/esd/common/cmd_loadpci.c
@@ -110,7 +110,7 @@ int do_loadpci(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 			 * Call run_cmd
 			 */
 			printf("running command at addr 0x%s ...\n", addr);
-			run_command((char*)la, 0);
+			builtin_run_command((char *)la, 0);
 			break;
 
 		default:
diff --git a/board/esd/du440/du440.c b/board/esd/du440/du440.c
index 426321e..75fb200 100644
--- a/board/esd/du440/du440.c
+++ b/board/esd/du440/du440.c
@@ -831,7 +831,7 @@ int do_time(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 	*d = '\0';
 
 	start = get_ticks();
-	ret = run_command (cmd, 0);
+	ret = builtin_run_command(cmd, 0);
 	end = get_ticks();
 
 	printf("ticks=%ld\n", (ulong)(end - start));
diff --git a/common/cmd_bedbug.c b/common/cmd_bedbug.c
index 87b108f..0228ee8 100644
--- a/common/cmd_bedbug.c
+++ b/common/cmd_bedbug.c
@@ -237,7 +237,7 @@ void bedbug_main_loop (unsigned long addr, struct pt_regs *regs)
 		if (len == -1)
 			printf ("<INTERRUPT>\n");
 		else
-			rc = run_command (lastcommand, flag);
+			rc = builtin_run_command(lastcommand, flag);
 
 		if (rc <= 0) {
 			/* invalid command or not repeatable, forget it */
diff --git a/common/cmd_bootm.c b/common/cmd_bootm.c
index d5745b1..2e3e159 100644
--- a/common/cmd_bootm.c
+++ b/common/cmd_bootm.c
@@ -1046,7 +1046,7 @@ int do_bootd(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 	int rcode = 0;
 
 #ifndef CONFIG_SYS_HUSH_PARSER
-	if (run_command(getenv("bootcmd"), flag) < 0)
+	if (builtin_run_command(getenv("bootcmd"), flag) < 0)
 		rcode = 1;
 #else
 	if (parse_string_outer(getenv("bootcmd"),
diff --git a/common/cmd_source.c b/common/cmd_source.c
index 16a627a..481241c 100644
--- a/common/cmd_source.c
+++ b/common/cmd_source.c
@@ -179,7 +179,7 @@ source (ulong addr, const char *fit_uname)
 				if (*line) {
 					debug ("** exec: \"%s\"\n",
 						line);
-					if (run_command (line, 0) < 0) {
+					if (builtin_run_command(line, 0) < 0) {
 						rcode = 1;
 						break;
 					}
@@ -189,7 +189,7 @@ source (ulong addr, const char *fit_uname)
 			++next;
 		}
 		if (rcode == 0 && *line)
-			rcode = (run_command(line, 0) >= 0);
+			rcode = (builtin_run_command(line, 0) >= 0);
 	}
 #endif
 	free (cmd);
diff --git a/include/common.h b/include/common.h
index 8f5331e..dd1b9ed 100644
--- a/include/common.h
+++ b/include/common.h
@@ -260,7 +260,7 @@ int	print_buffer (ulong addr, void* data, uint width, uint count, uint linelen);
 
 /* common/main.c */
 void	main_loop	(void);
-int	run_command	(const char *cmd, int flag);
+int builtin_run_command(const char *cmd, int flag);
 int run_command2(const char *cmd, int flag);
 int	readline	(const char *const prompt);
 int	readline_into_buffer(const char *const prompt, char *buffer,
diff --git a/common/main.c b/common/main.c
index defe2d4..e74ebdf 100644
--- a/common/main.c
+++ b/common/main.c
@@ -274,9 +274,10 @@ int run_command2(const char *cmd, int flag)
 {
 #ifndef CONFIG_SYS_HUSH_PARSER
 	/*
 	 * run_command can return 0 or 1 for success, so clean up its result.
 	 */
-	if (run_command(cmd, flag) == -1)
+	if (builtin_run_command(cmd, flag) == -1)
 		return 1;
 
 	return 0;
@@ -457,7 +458,7 @@ void main_loop (void)
 		if (len == -1)
 			puts ("<INTERRUPT>\n");
 		else
-			rc = run_command (lastcommand, flag);
+			rc = builtin_run_command(lastcommand, flag);
 
 		if (rc <= 0) {
 			/* invalid command or not repeatable, forget it */
@@ -1278,7 +1279,7 @@ static void process_macros (const char *input, char *output)
  * creates or modifies environment variables (like "bootp" does).
  */
 
-int run_command (const char *cmd, int flag)
+int builtin_run_command(const char *cmd, int flag)
 {
 	cmd_tbl_t *cmdtp;
 	char cmdbuf[CONFIG_SYS_CBSIZE];	/* working copy of cmd		*/
@@ -274,9 +274,10 @@ int run_command2(const char *cmd, int flag)
 #ifndef CONFIG_SYS_HUSH_PARSER
 	/*
-	 * run_command can return 0 or 1 for success, so clean up its result.
+	 * builtin_run_command can return 0 or 1 for success, so clean up
+	 * its result.
 	 */
-- 
1.7.7.3



More information about the U-Boot mailing list